==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/danmaku/AbstractDanmakuItem.java <==
package cc.thonly.reverie_dreams.item.danmaku;

import cc.thonly.reverie_dreams.Touhou;
import cc.thonly.reverie_dreams.component.ModDataComponentTypes;
import cc.thonly.reverie_dreams.item.base.IDanmakuItem;
import cc.thonly.reverie_dreams.sound.SoundEventInit;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import java.util.function.Consumer;

@Setter
@Getter
@ToString
public abstract class AbstractDanmakuItem extends class_1792 implements IDanmakuItem {
    public static final Integer DEFAULT_COUNT = 3;

    public AbstractDanmakuItem(class_1793 settings) {
        super(settings.method_7889(1));
    }

    @Override
    public class_1269 method_7884(class_1838 context) {
        if (!context.method_8045().method_8608()) {
            method_7836((class_3218) context.method_8045(),
                    (class_1657) context.method_8036(),
                    context.method_20287());
        }
        return class_1269.field_5812;
    }

    @Override
    public class_1269 method_7847(class_1799 stack, class_1657 user, class_1309 entity, class_1268 hand) {
        class_1937 world = user.method_37908();
        if (!world.method_8608()) {
            method_7836((class_3218) world,
                    user,
                    hand);
        }
        return class_1269.field_5812;
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        class_1799 itemStack = user.method_5998(hand);
        Boolean isInfinite = itemStack.method_58695(ModDataComponentTypes.Danmaku.INFINITE, false);
        if (!world.field_9236 && world instanceof class_3218 serverWorld) {
            var cooldownManager = user.method_7357();
            if (cooldownManager.method_7904(itemStack)) {
                return class_1269.field_5814;
            }
            cooldownManager.method_62835(itemStack, 10);
            for (int i = 0; i < itemStack.method_58695(ModDataComponentTypes.Danmaku.COUNT, DEFAULT_COUNT); i++) {
                this.shoot(serverWorld, user, hand);
            }
            if (!isInfinite) {
                itemStack.method_61653(1, user);
                if (itemStack.method_7963() && itemStack.method_7919() >= itemStack.method_7936()) {
                    itemStack.method_7934(1);
                }
            }

            world.method_43128(null, user.method_23317(), user.method_23318(), user.method_23321(), SoundEventInit.FIRE, class_3419.field_15254, 1f, 1.0f);
            user.method_6104(hand);
            return class_1269.field_52422;
        }
        user.method_7259(class_3468.field_15372.method_14956(this));
        return class_1269.field_5812;
    }

//    @Override
//    public void appendTooltip(ItemStack stack, TooltipContext context, TooltipDisplayComponent displayComponent, Consumer<Text> textConsumer, TooltipType type) {
//        Float damage = stack.getOrDefault(ModDataComponentTypes.Danmaku.DAMAGE, null);
//        Float scale = stack.getOrDefault(ModDataComponentTypes.Danmaku.SCALE, null);
//        Float speed = stack.getOrDefault(ModDataComponentTypes.Danmaku.SPEED, null);
//        Integer count = stack.getOrDefault(ModDataComponentTypes.Danmaku.COUNT, DEFAULT_COUNT);
//        String templateType = stack.getOrDefault(ModDataComponentTypes.Danmaku.TEMPLATE, Touhou.id("single").toString());
//
//        textConsumer.accept(Text.empty().append(Text.translatable("item.tooltip.damage")).append(String.valueOf(damage)));
//        textConsumer.accept(Text.empty().append(Text.translatable("item.tooltip.speed")).append(String.valueOf(speed)));
//        textConsumer.accept(Text.empty().append(Text.translatable("item.tooltip.count")).append(String.valueOf(count)));
//        textConsumer.accept(Text.empty().append(Text.translatable("item.tooltip.base_type")).append(Text.translatable(Identifier.of(templateType).toTranslationKey())));
//    }

    public abstract void shoot(class_3218 serverWorld, class_1309 user, class_1268 hand);
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/danmaku/AbstractDanmakuItem.java <==
package cc.thonly.reverie_dreams.item.danmaku;

import cc.thonly.reverie_dreams.component.DanmakuProperties;
import cc.thonly.reverie_dreams.registry.content.component.RDDataComponentTypes;
import cc.thonly.reverie_dreams.item.base.IDanmakuItem;
import cc.thonly.reverie_dreams.sound.SoundEventInit;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_3218;
import net.minecraft.class_3419;
import net.minecraft.class_3468;

@Setter
@Getter
@ToString
public abstract class AbstractDanmakuItem extends class_1792 implements IDanmakuItem {
    public AbstractDanmakuItem(class_1793 settings) {
        super(settings.method_7889(1));
    }

    @Override
    public class_1269 method_7884(class_1838 context) {
        if (!context.method_8045().method_8608()) {
            method_7836((class_3218) context.method_8045(),
                    (class_1657) context.method_8036(),
                    context.method_20287());
        }
        return class_1269.field_5812;
    }

    @Override
    public class_1269 method_7847(class_1799 stack, class_1657 user, class_1309 entity, class_1268 hand) {
        class_1937 world = user.method_37908();
        if (!world.method_8608()) {
            method_7836((class_3218) world,
                    user,
                    hand);
        }
        return class_1269.field_5812;
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        class_1799 itemStack = user.method_5998(hand);
        if (!world.field_9236 && world instanceof class_3218 serverWorld) {
            var cooldownManager = user.method_7357();
            if (cooldownManager.method_7904(itemStack)) {
                return class_1269.field_5814;
            }
            cooldownManager.method_62835(itemStack, 10);
            DanmakuProperties properties = itemStack.method_58695(RDDataComponentTypes.DANMAKU_PROPERTIES, DanmakuProperties.ofDefault());
            for (int i = 0; i < properties.getCount(); i++) {
                this.shoot(serverWorld, user, hand);
            }
            if (!properties.isInfinite()) {
                itemStack.method_61653(1, user);
                if (itemStack.method_7963() && itemStack.method_7919() >= itemStack.method_7936()) {
                    itemStack.method_7934(1);
                }
            }

            world.method_43128(null, user.method_23317(), user.method_23318(), user.method_23321(), SoundEventInit.FIRE, class_3419.field_15254, 1f, 1.0f);
            user.method_6104(hand);
            return class_1269.field_52422;
        }
        user.method_7259(class_3468.field_15372.method_14956(this));
        return class_1269.field_5812;
    }

    public abstract void shoot(class_3218 serverWorld, class_1309 user, class_1268 hand);
}
